function tone = note(keynum,dur,type)
% NOTE Produce a sinusoidal waveform corresponding to a
% given piano key number
%
% usage: tone = note (keynum, dur)
%
% tone = the output waveform
% keynum = the piano keyboard number of the desired note
% dur = the duration (in seconds) of the output note
% type = 'sine' (default), 'square', or 'sawtooth'
%
% keys = [ 40 42 44 45 47 49 51 52 ];
% --- NOTES C  D  E  F  G  A  B  C
% key #40 is middle-C

%
if (nargin<3)
    type = 'sine';
end
fs = 11025; %-- use 11025 Hz on PC/Mac, 8000 on UNIX
tt = 0:(1/fs):dur;
freq =(2^((keynum-49)/12))*440;
switch (type)
case 'square'
    arg = mod(freq*tt,1.0);
    tone = (2.0*rect(arg)-1.0)/sqrt(3);
case 'sawtooth'
     arg = mod(freq*tt,1.0)-0.5;
    tone = 2.0*tri(2.0*arg)-1.0;
otherwise
    tone =sin(2*pi*freq*tt)/sqrt(3/2);
end